@@ -3,6 +3,7 @@ from django.core.cache import cache
 from django.db import models
 from taggit.managers import TaggableManager
 from django.conf import settings
+from translator.util import get_key
 
 
 class Translation(models.Model):
@@ -20,5 +21,5 @@ class Translation(models.Model):
 
         all_translation_keys = Translation.objects.all().values_list('key', flat=True)
         for l in settings.LANGUAGES:
-            cache.delete_many(['{0}-{1}'.format(l[0], k) for k in all_translation_keys])
+            cache.delete_many([get_key(l[0], k) for k in all_translation_keys])
         return super(Translation,self).save(force_insert, force_update, using, update_fields)
