@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.utils.functional import lazy
 from django.utils.safestring import mark_safe
+import hashlib
 
 
 def get_translation_for_key(item):
@@ -10,7 +11,7 @@ def get_translation_for_key(item):
     from django.core.cache import cache
 
     lang = get_language()
-    key = u'{0}-{1}'.format(lang, item)
+    key = get_key(lang, item)
     result = cache.get(key)
     if not result:
         try:
@@ -24,6 +25,11 @@ def get_translation_for_key(item):
     return mark_safe(result)
 
 
+def get_key(lang, item):
+    item = hashlib.sha256(item).hexdigest()
+    key = u'{0}-{1}'.format(lang, item)
+    return key
+
 def translator(key):
     return get_translation_for_key(key)
 
